@@ -156,7 +156,7 @@ class QalxJob:
         )
 
     def add_step_result(self, success=True):
-        """indicate success and add info about the current step
+        """indicate success or failure of the step function
 
         :param success: was the step successful or not
         :type success: bool
@@ -182,8 +182,8 @@ class QalxJob:
         :type entity_type: str
         :param entity_guid: the guid of the entity
         :type entity_guid: str
-        :return:    a child of pyqalx.core.entities.QalxEntity if the entity is
-                    found on the API, otherwise None
+        :return:    a child of :class:`~pyqalx.core.entities.entity.QalxEntity`
+                    if the entity is found on the API, otherwise None
         """
         adapter = getattr(self.session, entity_type)
         self.entity_adapter = adapter
@@ -202,13 +202,13 @@ class QalxJob:
 
     def add_item_data(self, item_key, data, meta=None):
         """
-        helper method to add data item to the set
+        helper method to add item data to the set
 
         :param item_key: key on the set to add the item as
         :type item_key: str
         :param data: data to add
         :type data: dict
-        :param meta: metadata
+        :param meta: metadata to add
         :type meta: dict
 
         :return: The specific :class:`~pyqalx.core.entities.item.Item` instance
@@ -257,6 +257,12 @@ class QalxJob:
 
 
 class Bot:
+    """
+    Bots allow automation of tasks.  A bot reads messages from a
+    :class:`~pyqalx.core.entities.queue.Queue` and processes the response
+    through user configured `step_functions`.
+    """
+
     __slots__ = (
         "name",
         "queue_name",
@@ -334,29 +340,37 @@ class Bot:
         workflow=None,
     ):
         """
+        Starts the bot with `processes` number of :class:`~pyqalx.bot.Worker`
+        instances.  Each worker will be able to read a message from the queue
+        in parallel
+
         :param queue_name: The unique name for the queue
         :type queue_name: str
-        :param qalx_session_class: The QalxSession class that this Bot and
-        Workers should use
-        :param user_config_class: The UserConfig class that will be used when
-        creating the Bot
-        :type user_config_class: `~configs.UserConfig` or subclass
-        :param bot_config_class: The BotConfig class that will be used when
-        using the bot session
-        :type: str
-        :param entity_classes: A list of `QalxEntity` subclasses that you want
-        this Bot to use once it is started
-        :type: list
+        :param qalx_session_class: The :class:`~pyqalx.core.session.QalxSession`
+                                   class that this Bot and Workers should use
+        :type qalx_session_class: pyqalx.core.session.QalxSession
+        :param user_config_class: The :class:`~pyqalx.config.configs.UserConfig`
+                                  class that will be used when creating the Bot
+        :type user_config_class: pyqalx.config.configs.UserConfig
+        :param bot_config_class: The :class:`~pyqalx.config.configs.BotConfig`
+                                 class that will be used when using the bot session
+        :type bot_config_class: pyqalx.config.configs.BotConfig
+        :param entity_classes: A list of
+                               :class:`~pyqalx.core.entities.entity.QalxEntity`
+                               subclasses that you want this Bot to use once
+                               it is started
+        :type entity_classes: list
         :param user_profile_name: The user profile name that will be used when
                                   creating the Bot
-        :type user_profile_name: string
+        :type user_profile_name: str
         :param bot_profile_name: The bot profile name that will be used when
                                  using the bot session
-        :type bot_profile_name: string
+        :type bot_profile_name: str
         :param skip_ini: Should reading from the `ini` file be skipped when
                          instantiating the user and bot sessions
         :type skip_ini: bool
-        :param processes: The number of processes this bot should spawn
+        :param processes: The number of :class:`~pyqalx.bot.Worker` processes
+                          this bot should spawn
         :type processes: int
         :param stop:    Should the bot be stopped right after startup. This is
                         essential functionality during factory building
@@ -404,8 +418,11 @@ class Bot:
         )
         queue = user_session.queue.get_or_create(name=self.queue_name)
         # Add the queue_name - this makes it easier to find bots looking at
-        # specific queues.
-        bot_session.config.update({"queue_name": self.queue_name})
+        # specific queues. Also add the `_region` in case the queue gets
+        # reloaded by the worker (which will be using the `bot_session`)
+        bot_session.config.update(
+            {"queue_name": self.queue_name, "REGION": queue._region}
+        )
         # Log all the user and bot session config values for debugging
         for session, title in zip((user_session, bot_session), ("user", "bot")):
             session.log.debug(f"-vvv- Config values for {title} session -vvv-")
@@ -424,7 +441,7 @@ class Bot:
         if self.initialisation_function:
             init_result = self.initialisation_function(user_session)
             bot_session.log.debug(
-                f"Initialisation function returns {init_result}"
+                f"Initialisation function returns `{init_result}`"
             )
             if not init_result:
                 raise QalxBotInitialisationFailed(
@@ -460,7 +477,7 @@ class Bot:
                 )
             )
             bot_session.log.debug(
-                f"Created worker {worker} to read from {self.queue_name}"
+                f"Created worker `{worker}` to read from `{self.queue_name}`"
             )
         for p in workers:
             p.start()
@@ -488,6 +505,7 @@ class Bot:
         """decorator to to register the begin
 
         `begin` is executed with a QalxJob instance
+
         :param func: function to be executed
         """
         self.begin_function = func
@@ -496,6 +514,7 @@ class Bot:
         """decorator executed before entity is loaded from qalx.
 
         `preload` is executed with a QalxJob instance
+
         :param func: function to be executed
         """
         self.preload_function = func
@@ -504,6 +523,7 @@ class Bot:
         """decorator to register the onload
 
         `onload` is executed with a QalxJob instance
+
         :param func: function to be executed
         """
         self.onload_function = func
@@ -512,6 +532,7 @@ class Bot:
         """decorator to register preprocess function
 
         `preprocess` is executed with a QalxJob instance
+
         :param func: function to register
         """
         self.preprocess_function = func
@@ -520,6 +541,7 @@ class Bot:
         """decorator to register process function
 
         `process` is executed with a QalxJob instance
+
         :param func: function to register
         """
         self.process_function = func
@@ -528,6 +550,7 @@ class Bot:
         """decorator to register precompletion function
 
         `precompletion` is executed with a QalxJob instance
+
         :param func: function to register
         """
         self.precompletion_function = func
@@ -536,6 +559,7 @@ class Bot:
         """decorator to register postprocess function
 
         `postprocess` is executed with a QalxJob instance
+
         :param func: function to register
         """
         self.postprocess_function = func
@@ -544,6 +568,7 @@ class Bot:
         """decorator to register onwait function
 
         `onwait` is executed with a QalxJob instance
+
         :param func: function to register
         """
         self.onwait_function = func
@@ -552,6 +577,7 @@ class Bot:
         """decorator to register ontermination function
 
         `ontermination` is executed with a QalxJob instance
+
         :param func: function to register
         """
         self.ontermination_function = func
@@ -773,7 +799,7 @@ class Worker(Process):
         # avoid pickle errors
         self.steps = {}
         for f_name, f_dill in self._steps.items():  # de-serialise functions
-            self.log.debug(f"try to undill step {f_name}")
+            self.log.debug(f"try to undill step `{f_name}`")
             try:
                 self.steps[f_name] = dill.loads(f_dill)
             except TypeError:
