@@ -7,6 +7,11 @@ from pyqalx.core.signals import QalxWorkerSignal
 
 
 class QalxWorker(QalxSignalAdapter, QalxUpdateStatusAdapter):
+    """
+    Provides an interface for accessing the API for
+    :class:`~pyqalx.core.entities.worker.Worker` entities
+    """
+
     _entity_class = Worker
     signal_class = QalxWorkerSignal
 
@@ -25,7 +30,7 @@ class QalxWorker(QalxSignalAdapter, QalxUpdateStatusAdapter):
         """
         Builds the list_endpoint for workers.  This requires the bot_entity
         which will get passed down from the calling method via kwargs.
-        :param bot_entity:An instance of ~entities.bot.Bot
+        :param bot_entity:An instance of Bot
         :type bot_entity:~entities.bot.Bot
         :return:The Worker list endpoint
         """
@@ -36,11 +41,12 @@ class QalxWorker(QalxSignalAdapter, QalxUpdateStatusAdapter):
         """
         Builds the detail_endpoint for workers.  This requires the bot_entity
         which will get passed down from the calling method via kwargs.
-        :param guid:The guid of the Worker
-        :type guid:guid
-        :param bot_entity:An instance of ~entities.bot.Bot
-        :type bot_entity:~entities.bot.Bot
-        :return:The Worker list endpoint
+
+        :param guid: The guid of the Worker
+        :type guid: `uuid`
+        :param bot_entity: An instance of Bot
+        :type bot_entity: ~pyqalx.core.entities.bot.Bot
+        :return: The Worker list endpoint
         """
         bot_endpoint = self.list_endpoint(bot_entity=bot_entity)
         return f"{bot_endpoint}/{guid}"
@@ -48,10 +54,12 @@ class QalxWorker(QalxSignalAdapter, QalxUpdateStatusAdapter):
     def get(self, guid, bot_entity, *args, **kwargs):
         """
         Gets an individual worker.
-        :param guid:The guid of the Worker
-        :type guid: guid
-        :param bot_entity:An instance of ~entities.bot.Bot
-        :type bot_entity:~entities.bot.Bot
+
+        :param guid: The guid of the Worker
+        :type guid: `uuid`
+        :param bot_entity: An instance of Bot
+        :type bot_entity: ~pyqalx.core.entities.bot.Bot
+        :return: :class:`~pyqalx.core.entities.worker.Worker`
         """
         return super(QalxWorker, self).get(
             guid, bot_entity=bot_entity, *args, **kwargs
@@ -60,10 +68,12 @@ class QalxWorker(QalxSignalAdapter, QalxUpdateStatusAdapter):
     def get_signal(self, entity, bot_entity, *args, **kwargs):
         """
         Gets the signal for a specific entity
-        :param entity:An instance of ~entities.worker.Worker
-        :type entity:~entities.worker.Worker
-        :param bot_entity:An instance of ~entities.bot.Bot
-        :type bot_entity:~entities.bot.Bot
+
+        :param entity: An instance of Worker
+        :type entity: ~pyqalx.core.entities.worker.Worker
+        :param bot_entity: An instance of Bot
+        :type bot_entity: ~pyqalx.core.entities.bot.Bot
+        :return: :class:`~pyqalx.core.signals.QalxWorkerSignal`
         """
         return super(QalxWorker, self).get_signal(
             entity=entity, bot_entity=bot_entity, *args, **kwargs
@@ -72,10 +82,11 @@ class QalxWorker(QalxSignalAdapter, QalxUpdateStatusAdapter):
     def terminate(self, entity, bot_entity, *args, **kwargs):
         """
         Terminates a specific entity
-        :param entity:An instance of ~entities.worker.Worker
-        :type entity:~entities.worker.Worker
-        :param bot_entity:An instance of ~entities.bot.Bot
-        :type bot_entity:~entities.bot.Bot
+
+        :param entity: An instance of Worker
+        :type entity: ~pyqalx.core.entities.worker.Worker
+        :param bot_entity: An instance of Bot
+        :type bot_entity: ~pyqalx.core.entities.bot.Bot
         """
         return super(QalxWorker, self).terminate(
             entity=entity, bot_entity=bot_entity, *args, **kwargs
@@ -84,12 +95,13 @@ class QalxWorker(QalxSignalAdapter, QalxUpdateStatusAdapter):
     def _stop_or_resume(self, entity, stop, bot_entity, **kwargs):
         """
         Stops or resumes a specific entity
-        :param entity:An instance of ~entities.worker.Worker
-        :type entity:~entities.worker.Worker
-        :param stop:Whether we should stop or resume
-        :type stop:bool
-        :param bot_entity:An instance of ~entities.bot.Bot
-        :type bot_entity:~entities.bot.Bot
+
+        :param entity: An instance of Worker
+        :type entity: ~pyqalx.core.entities.worker.Worker
+        :param stop: Whether we should stop or resume
+        :type stop: bool
+        :param bot_entity: An instance of Bot
+        :type bot_entity: ~pyqalx.core.entities.bot.Bot
         """
         return super(QalxWorker, self)._stop_or_resume(
             entity=entity, stop=stop, bot_entity=bot_entity, **kwargs
@@ -98,11 +110,12 @@ class QalxWorker(QalxSignalAdapter, QalxUpdateStatusAdapter):
     def reload(self, entity, bot_entity, **kwargs):
         """
         Reloads the current entity from the API
-        :param entity: An instance of ~entities.worker.Worker
-        :type entity:~entities.worker.Worker
-        :param bot_entity: An instance of ~entities.bot.Bot
-        :type bot_entity:~entities.bot.Bot
-        :return: A refreshed instance of `self.entity`
+
+        :param entity: An instance of Worker
+        :type entity: ~pyqalx.core.entities.worker.Worker
+        :param bot_entity: An instance of Bot
+        :type bot_entity: ~pyqalx.core.entities.bot.Bot
+        :return: :class:`~pyqalx.core.entities.worker.Worker`
         """
         return super(QalxWorker, self).reload(
             entity=entity, bot_entity=bot_entity
@@ -111,10 +124,11 @@ class QalxWorker(QalxSignalAdapter, QalxUpdateStatusAdapter):
     def update_status(self, entity, bot_entity, status):
         """
         Updates the workers status
-        :param entity: An instance of ~entities.worker.Worker
-        :type entity:~entities.worker.Worker
-        :param bot_entity: An instance of ~entities.bot.Bot
-        :type bot_entity:~entities.bot.Bot
+
+        :param entity: An instance of Worker
+        :type entity: ~pyqalx.core.entities.worker.Worker
+        :param bot_entity: An instance of Bot
+        :type bot_entity: ~pyqalx.core.entities.bot.Bot
         :param status: The status to update to
         :type status: str
         """
@@ -125,10 +139,11 @@ class QalxWorker(QalxSignalAdapter, QalxUpdateStatusAdapter):
     def stop(self, entity, bot_entity, **kwargs):
         """
         Sends a stop signal to the worker
-        :param entity: An instance of ~entities.worker.Worker
-        :type entity:~entities.worker.Worker
-        :param bot_entity: An instance of ~entities.bot.Bot
-        :type bot_entity:~entities.bot.Bot
+
+        :param entity: An instance of Worker
+        :type entity: ~pyqalx.core.entities.worker.Worker
+        :param bot_entity: An instance of Bot
+        :type bot_entity: ~pyqalx.core.entities.bot.Bot
         """
         return super(QalxWorker, self).stop(
             entity=entity, bot_entity=bot_entity, **kwargs
@@ -137,16 +152,26 @@ class QalxWorker(QalxSignalAdapter, QalxUpdateStatusAdapter):
     def resume(self, entity, bot_entity, **kwargs):
         """
         Sends a resume signal to the worker
-        :param entity: An instance of ~entities.worker.Worker
-        :type entity:~entities.worker.Worker
-        :param bot_entity: An instance of ~entities.bot.Bot
-        :type bot_entity:~entities.bot.Bot
+
+        :param entity: An instance of Worker
+        :type entity: ~pyqalx.core.entities.worker.Worker
+        :param bot_entity: An instance of Bot
+        :type bot_entity: ~pyqalx.core.entities.bot.Bot
         """
         return super(QalxWorker, self).resume(
             entity=entity, bot_entity=bot_entity, **kwargs
         )
 
     def save(self, entity, bot_entity, *args, **kwargs):
+        """
+        Saves the Worker instance
+
+        :param entity: An instance of Worker
+        :type entity: ~pyqalx.core.entities.worker.Worker
+        :param bot_entity: An instance of Bot
+        :type bot_entity: ~pyqalx.core.entities.bot.Bot
+        :return: :class:`~pyqalx.core.entities.worker.Worker`
+        """
         return super(QalxWorker, self).save(
             entity=entity, bot_entity=bot_entity, *args, **kwargs
         )
