@@ -16,26 +16,24 @@ class QueueResponse:
     def __init__(self, response):
         """make new response
 
-        v0.1 - doesn't do much yet
         :param response: response from queue
         """
         self._raw_response = response
 
 
 class QueueMessage(threading.Thread):
-    """a message frm the queue.  subclasses threading.Thread so that a
+    """a message from the queue.  subclasses `threading.Thread` so that a
     heartbeat can be started as soon as the message is received from the Queue
-
-    attributes:
-        body: message body
-        receipt_handle: some information to return to the message broker to
-        confirm receipt
     """
 
     def __init__(self, message, worker, visibility, *args, **kwargs):
         """
-
         :param message: the full raw message from the queue
+        :type message: dict
+        :param worker: An instance of :class:~pyqalx.bot.Worker
+        :type worker: ~pyqalx.bot.Worker
+        :param visibility: How long should the heartbeat "beat" for (in seconds)?
+        :type visibility: int
         """
         super(QueueMessage, self).__init__(*args, **kwargs)
         self._raw_message = message
@@ -121,17 +119,18 @@ class QueueMessage(threading.Thread):
         """
         A QalxJob might take a long time to process.  Therefore, we
         use a heartbeat on the message to keep it in flight for as long
-        as possible.  This runs in a Thread on QueueMessage instantiation
+        as possible.  This runs in a Thread
+        on :class:`~pyqalx.core.entities.queue.QueueMessage` instantiation
         to ensure that the message timeout doesn't expire before processing
         even begins (i.e. if a batch of messages was returned)
-        As per the SQS docs at:
 
-        https://docs.aws.amazon.com/AWSSimpleQueueService/latest
-        /SQSDeveloperGuide/sqs-visibility-timeout.html
+        As per the SQS docs `here
+        <https://docs.aws.amazon.com/AWSSimpleQueueService
+        /latest/SQSDeveloperGuide/sqs-visibility-timeout.html>`_
 
         This will specify the initial visibility timeout (for example, 2 minutes)
-        and then—as long as your consumer still works on
-        the message—keep extending the visibility timeout by 2
+        and then — as long as your consumer still works on
+        the message — keep extending the visibility timeout by 2
         minutes every minute.
         This uses `visibility` as the initial visibility timeout so every
         `visibility / 2` seconds will increase the timeout by
@@ -169,12 +168,7 @@ class QueueMessage(threading.Thread):
 
 
 class Queue(QalxEntity):
-    """QalxEntity with entity_type Queue
-
-    attributes:
-        broker_client: an authenticated client to communicate with the remote
-        message broker
-    """
+    """QalxEntity with entity_type Queue"""
 
     entity_type = "queue"
 
@@ -194,6 +188,8 @@ class Queue(QalxEntity):
     @property
     def broker_client(self):
         """
+        An authenticated client to communicate with the remote message broker.
+
         Windows can't pickle the client if it gets set on __init__ therefore,
         we set it to an internal attribute and cache it for the duration of
         the Queue to avoid getting the client multiple times
@@ -206,7 +202,7 @@ class Queue(QalxEntity):
 
             _broker_client = boto3.client(
                 "sqs",
-                region_name="eu-west-2",  # TODO: #2756 make this configurable
+                region_name=self._region,
                 aws_access_key_id=self["info"]["credentials"]["ACCESS_KEY_ID"],
                 aws_secret_access_key=self["info"]["credentials"][
                     "SECRET_ACCESS_KEY"
@@ -233,11 +229,15 @@ class Queue(QalxEntity):
         get messages from the queue
 
         :param max_num_msg: maximum number to retrieve
+        :type max_num_msg: int
         :param visibility: time in seconds until the message becomes visible
                            again on the queue
+        :type visibility: int
         :param waittime: time to wait for a message
-        :param worker: The ~pyqalx.bot.Worker instance that called this method
-        :return: list of `pyqalx.core.entities.queue.QueueMessage`
+        :type waittime: int
+        :param worker: The :class:`~pyqalx.bot.Worker` instance that called this method
+        :type worker: ~pyqalx.bot.Worker
+        :return: List of :class:`~pyqalx.core.entities.queue.QueueMessage`
         """
 
         responses = self.broker_client.receive_message(
@@ -259,8 +259,7 @@ class Queue(QalxEntity):
         """remove message from the queue
 
         :param message: message to delete
-        :type message: `QalxMessage`
-        :return: None
+        :type message: :class:`~pyqalx.core.entities.queue.QueueMessage`
         """
         if message is not None:
             # message could be None if the job it's been
@@ -276,19 +275,22 @@ class Queue(QalxEntity):
         Batch submits the given payload to the instance of Queue.  Figures out
         whether the payload is a subclass of QalxEntity, a string or a list of
         a combination.  Typically this will be invoked via the entity class itself:
-        i.e. `EntityClass.add_to_queue(entity, queue)`.
-        :param payload:A subclassed instance of QalxEntity, a guid string or a list
-        of QalxEntities/guids
+
+        >>> EntityClass.add_to_queue(entity, queue)
+        >>> queue._send_message(<entity_instance>)
+        >>> queue._send_message(<entity_guid>)
+        >>> queue._send_message([<entity_instance>,
+        ...                      <entity_instance>,
+        ...                      <entity_instance>])
+        >>> queue._send_message([<entity_guid>, <entity_guid>, <entity_guid>])
+
+        :param payload: A subclassed instance of QalxEntity, a guid string or a list
+                        of QalxEntities/guids
         :type payload:QalxEntity or str
         :param entity_type:The entity type
         :type entity_type: str
         :param message_kwargs:Additional arguments that should be added to the
-        message body
-        Usage:
-        queue._send_message(<entity_instance>)
-        queue._send_message(<entity_guid>)
-        queue._send_message([<entity_instance>, <entity_instance>, <entity_instance>])
-        queue._send_message([<entity_guid>, <entity_guid>, <entity_guid>])
+                              message body
         :return:An instance of QueueResponse
         """
 
