@@ -75,15 +75,17 @@ class QalxLogFormatter(logging.Formatter):
 def configure_logging(name, filename, level):
     """
     Configures a log.  Loggers are tied directly to an instance of
-    QalxSession or Worker and should be accessed via `instance.log.<level>`.
+    :class:`~pyqalx.core.session.QalxSession` or :class:`~pyqalx.bot.Worker`
+    and should be accessed via `instance.log.<level>`.
     All pyqalx loggers are prefixed with `<LOGGER_NAME_PREFIX>`
+
     :param name: The name of the log
-    :type name:str
+    :type name: str
     :param filename: The full filename for where the log should be saved
-    :type filename:str
+    :type filename: str
     :param level: The level of the log
-    :type level:str
-    :return:
+    :type level: str
+    :return: logging.getLogger()
     """
     name = f"{LOGGER_NAME_PREFIX}.{name}"
     if isinstance(level, str):
@@ -103,10 +105,11 @@ def session_logging_suffix(config):
     """
     Returns the suffix to use for QalxSession logging instances based
     on the config
-    :param config:The Config class/instance
-    :type config:A subclass or instance of Config
-    :return:The key_prefix split.
-    i.e. `user` for `QALX_USER_` and `bot` for `QALX_BOT_`
+
+    :param config: A subclass of :class:`~pyqalx.config.configs.Config`
+    :type config: ~pyqalx.config.configs.Config
+    :return: The key_prefix split.
+             i.e. `user` for `QALX_USER_` and `bot` for `QALX_BOT_`
     """
     return config.key_prefix.split("_")[1].lower()
 
