@@ -28,6 +28,10 @@ class Factory(BaseFactory):
     def validate(self, plan):
         """
         Calls the validate method on the adapter
+
+        :param plan: Path to a .yaml file containing the definition of the factory plan
+        :type plan: str
+        :raises QalxFactoryValidationError: If there is a problem validating the plan
         """
         self._msg_user(msg="Starting Factory Validation")
         self.session.factory.validate(plan)
@@ -77,6 +81,7 @@ class Factory(BaseFactory):
         :type  plan:    str
         :param stage:   Stage to be built
         :type  stage:   str
+        :raises QalxFactoryBuildError: - if there is a problem with the build
         """
         self._msg_user(msg="Starting Factory Build")
         self.stage = stage
@@ -87,13 +92,26 @@ class Factory(BaseFactory):
             self.session.tags.add(name=key, value=val)
 
         def _delete_resources(_delete_stacks=True):
-            self._delete_resources(delete_stacks=_delete_stacks)
-            # Message the user and raise an exception
-            _error = (
-                "Factory Build Failed. No bots on this factory "
-                "have been started. Created resources have been "
-                "deleted. See the logs for more details"
-            )
+            """
+            The build could fail in numerous places.  This private method handles
+            consistent messaging and the actual deletion depending on the debug
+            value
+            """
+            if self._plan_debug._demolish_on_failure:
+                self._delete_resources(delete_stacks=_delete_stacks)
+                # Message the user and raise an exception
+                _error = (
+                    "Factory Build Failed. No bots on this factory "
+                    "have been started. Created resources have been "
+                    "deleted. See the logs for more details"
+                )
+            else:
+                # We aren't deleting resources despite the build failure.
+                # Explicitly inform the user
+                _error = (
+                    f"Factory Build Failed. "
+                    f"{self._plan_debug._demolish_on_failure_msg}"
+                )
             self._msg_user(msg=_error, title="pyqalx", level=logging.ERROR)
             raise QalxFactoryBuildError(_error)
 
