@@ -12,7 +12,14 @@ import sys
 import uuid
 from time import sleep
 
-import git
+from pyqalx.factories.debug import FactoryPlanDebug
+
+try:
+    import git
+except ImportError:
+    # ImportError: Most likely git is not in the expected place.  Not an issue
+    #   unless the user wants to use bot_sources.GitBotSource
+    pass
 import os
 import stat
 import yaml
@@ -93,7 +100,8 @@ class FactoryPackMixin:
         this will use a random uuid as we won't have a Factory entity as the
         point of packing.
 
-        :raises:QalxFactoryPackError if the directory can not be created.
+        :raises QalxFactoryPackError: if
+                 the directory can not be created.
         """
         try:
             os.makedirs(self.build_path)
@@ -151,7 +159,7 @@ class FactoryPackMixin:
 
         :param bots:    A dictionary of {bot_name:bot_source}
         :type  bots:    dict
-        :raises:QalxFactoryPackError
+        :raises QalxFactoryPackError:
         """
         results = []
         exception = None
@@ -599,13 +607,16 @@ class FactoryBuildMixin:
         if providers:
             # Only run the manager if there are providers - if there aren't
             # any then there was a config error with one/all the providers
-            manager = SectorManager(providers=list(providers.values()))
+            manager = SectorManager(
+                providers=list(providers.values()), plan_debug=self._plan_debug
+            )
             manager._monitor_stack_creation()
             all_completed = manager._all_completed()
 
-        if all_completed:
+        if all_completed or self._plan_debug._demolish_on_failure is False:
             # Add the stack mappings to the entity if the stacks
-            # created successfully.
+            # created successfully or if we the debug key is set to not demolish
+            # on failure.
             self.entity["stacks"] = stack_mapping
             self.session.factory.save(self.entity)
         return all_completed
@@ -833,6 +844,16 @@ class BaseFactory(
         bot_profile=BotConfig.default,
         aws_profile=default_aws_profile,
     ):
+        """
+        :param session: An instance of :class:`~pyqalx.core.session.QalxSession`
+        :type session: ~pyqalx.core.session.QalxSession
+        :param user_profile: The user profile to use
+        :type user_profile: str
+        :param bot_profile: The bot profile to user
+        :type bot_profile: str
+        :param aws_profile: The AWS profile to use
+        :type aws_profile: str
+        """
         self.session = session
         self.user_profile = user_profile
         self.bot_profile = bot_profile
@@ -883,7 +904,7 @@ class BaseFactory(
         If given a UUID string will get the factory from the API
         :param factory: An instance of ~pyqalx.core.entities.factory.Factory
         or a uuid as a string
-        :raises: ValueError if incorrect instance
+        :raises ValueError: if incorrect instance
         """
 
         if not isinstance(factory, FactoryEntity):
@@ -941,6 +962,10 @@ class BaseFactory(
             raise QalxFactoryError("`plan` must be set on the instance")
         return self.plan["factory"]
 
+    @property
+    def _plan_debug(self):
+        return FactoryPlanDebug(self._plan_factory.get("debug", {}))
+
     @property
     def _plan_name(self):
         return self._plan_factory["name"]
@@ -1026,8 +1051,7 @@ class BaseFactory(
     def bots(self):
         """
         :return: A map of {(<bot_guid>, <plan_bot_name>): <bot_entity>}
-                for the bots on the factory
-        entity
+                for the bots on the factory entity
         """
         if self._bots is None:
             self._bots = {}
